# jt_ops (Python 3.7+)
###### Author: [Joe Tilsed](http://linkedin.com/in/joetilsed/) | Created: 28.10.2019 | Last Updated: 28.10.2019

### Requirements:
- Python 3.7+

### Helpful Links:
- [Python Download](https://python.org/download)
- [Joe Tilsed Linked In](https://linkedin.com/in/joetilsed/)


###### # That's all folks...
